package storage

import (
	"encoding/binary"
	"fmt"
)

func GetUsedDuration(deviceId string) (uint64, error) {
	if len(deviceId) == 0 {
		return 0, nil
	}
	key := generateDeviceIdUsedKey(deviceId)
	value, err := get(key)
	if err != nil {
		return 0, nil
	}
	data := binary.BigEndian.Uint64(value)
	return data, nil
}

func SetUsedDuration(deviceId string, duration uint64) error {
	if len(deviceId) == 0 {
		return nil
	}
	existed, err := GetUsedDuration(deviceId)
	if err != nil {
		return err
	}
	if existed <= duration {
		key := generateDeviceIdUsedKey(deviceId)
		data := make([]byte, 8)
		binary.BigEndian.PutUint64(data, duration)
		return set(key, data)
	}
	return nil
}

func generateDeviceIdUsedKey(deviceId string) string {
	return fmt.Sprintf("device:%s:used", deviceId)
}
